@@ -5,41 +5,33 @@ use warnings;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.2_04';
+our $VERSION = '0.13_02';
 
 sub create {
 
     my ( $self, $vendor_apikey ) = @_;
 	### use low api ###
 	# make request and replace apikey
-	my $req = $self->make_request("POST", "users.json", undef, undef, { apikey => $vendor_apikey });
-	#my %query_form = $req->uri->query_form;
-	#$query_form{apikey} = $vendor_apikey;
-	#$req->uri->query_form(%query_form);
+	my $req = $self->make_request("POST", "users.json");
+	my %query_form = $req->uri->query_form;
+	$query_form{apikey} = $vendor_apikey;
+	$req->uri->query_form(%query_form);
 
 	# return HTTP::Response
 	my $res = $self->_request($req);
     return $self->_response2ref( $res );
 }
 
-sub update {
-
-    my ( $self, $update_apikey ) = @_;
-	my $req = $self->make_request("PUT", "users/apikey", undef, undef, { apikey => $update_apikey });
-	my $res = $self->_request($req);
-    return $self->_response2ref( $res );
-}
-
 sub destroy {
 
     my ( $self, $delete_apikey ) = @_;
 
 	### use low api ###
 	# make request and replace apikey
-	my $req = $self->make_request("DELETE", "users.json", undef, undef, { apikey => $delete_apikey });
-	#my %query_form = $req->uri->query_form;
-	#$query_form{apikey} = $delete_apikey;
-	#$req->uri->query_form(%query_form);
+	my $req = $self->make_request("DELETE", "users.json");
+	my %query_form = $req->uri->query_form;
+	$query_form{apikey} = $delete_apikey;
+	$req->uri->query_form(%query_form);
 
 	# return HTTP::Response
 	my $res = $self->_request($req);
@@ -56,7 +48,7 @@ WWW::Giraffi::API::User - Giraffi API User Method Access Module
 
 =head1 VERSION
 
-0.2_04
+0.13_02
 
 =head1 SYNOPSIS
 
@@ -99,17 +91,6 @@ Return Reference:
                 }
     };
 
-=head2 update
-
-Update user apikey
-
-Example:
-
-  my $update_apikey = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxx";
-  $ create user object
-  my $user = $g->user;
-  $user->update($delete_apikey);
-
 =head2 destroy
 
 Delete user and apikey
